"""
Do simulations for StochPy
==========================

Output is printed in benchmarking.out

Written by TR Maarleveld, Amsterdam, The Netherlands
E-mail: tmd200@users.sourceforge.net
Last Change: July 08, 2013
"""

def getFrames():
    """ get the number of frames for the StochKit and Cain simulations """
    n_frames = 0
    for i in xrange(n_trajectories):    
        smod.GetTrajectoryData(i+1)
        n_frames += smod.data_stochsim.simulation_timesteps    
    n_frames/=n_trajectories
    return n_frames
    
import copy,os,numpy as np
model_dir = os.path.join(os.getcwd(),'models')
import stochpy
smod = stochpy.SSA()

file_out = open('benchmarking_single.out','w')
file_out.write("Type\tStochPy")

file_out.write("1 Short simulation")
smod.Model('ImmigrationDeath.psc',model_dir)
L_sim_times = []
for x in xrange(10):
    smod.DoStochSim(end=1000,mode='steps')    
    L_sim_times.append(smod.simulation_time)
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("1 Long simulation")
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=10**6,mode='steps')    
    L_sim_times.append(smod.simulation_time)  
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("2 Short Simulation & non mass-action")
smod.Model('CellDivision.psc',model_dir)
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=1000,mode='steps',trajectories=1)   
    L_sim_times.append(smod.simulation_time)
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("2 Long Simulation & non mass-action")
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=10**6,mode='steps',trajectories=1)   
    L_sim_times.append(smod.simulation_time)
file_out.write("\t%s" % np.mean(L_sim_times))


file_out.write("3 Parallel Short simulation")
smod.Model('ImmigrationDeath.psc',model_dir)
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=1000,mode='steps',trajectories=100)    
    L_sim_times.append(smod.simulation_time)  
file_out.write("\t%s" % np.mean(L_sim_times))
 
file_out.write("3 Parallel Long simulation")
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=10**6,mode='steps',trajectories=10)    
    L_sim_times.append(smod.simulation_time)      
file_out.write("\t%s" % np.mean(L_sim_times))


file_out.write("4 Short Simulation & Parallel & Time Event")
smod.Model('dsmts-003-03.xml.psc',model_dir)
L_sim_times = []
for x in xrange(10):   
    smod.DoStochSim(end=50,mode='time',trajectories=n_trajectories)
    L_sim_times.append(smod.simulation_time)    
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("4 Long Simulation & Parallel & Time Event")
L_sim_times = []
for x in xrange(10):   
    smod.DoStochSim(end=10**6,mode='steps',trajectories=10)
    L_sim_times.append(smod.simulation_time)    
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("5 Short Simulation & Parallel & Amount Event")
smod.Model('dsmts-003-04.xml.psc',model_dir)
L_sim_times = []
for x in xrange(10):   
    smod.DoStochSim(end=50,mode='time',trajectories=n_trajectories)
    L_sim_times.append(smod.simulation_time)    
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("5 Long Simulation & Parallel & Amount Event")
L_sim_times = []
for x in xrange(10):   
    smod.DoStochSim(end=10**6,mode='steps',trajectories=10)
    L_sim_times.append(smod.simulation_time)    
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("6 Assignments & Parallel")
smod.Model('dsmts-001-19.xml.psc',model_dir)
L_sim_times = []
for x in xrange(10):   
    smod.DoStochSim(end=50,mode='time',trajectories=n_trajectories)
    L_sim_times.append(smod.simulation_time)    
file_out.write("\t%s" % np.mean(L_sim_times))

file_out.write("7 Large")
smod.Model('chain50.psc')
L_sim_times = []
for x in xrange(10):        
    smod.DoStochSim(end=10**5,trajectories=1)
    simulation_endtime = smod.data_stochsim.simulation_endtime
    L_sim_times.append(smod.simulation_time)    
file_out.write("%s\n" % np.mean(L_sim_times))

file_out.write("8 XL")
smod.Model('chain500.psc')
L_sim_times = []
for x in xrange(10): 
    smod.DoStochSim(end=5*10**4,trajectories=1)
    simulation_endtime = smod.data_stochsim.simulation_endtime
    L_sim_times.append(smod.simulation_time)   

file_out.write("9 XXL")
smod.Model('chain1500.psc')
L_sim_times = []
for x in xrange(10):     
    smod.DoStochSim(end=2.5*10**4,trajectories=1)
    simulation_endtime = smod.data_stochsim.simulation_endtime
    L_sim_times.append(smod.simulation_time)   
file_out.write("%s\n" % np.mean(L_sim_times))
